NlpResult class

Constructors

NlpResult({required String action, required String resolvedQuery, required Map<String, String> params})

Properties

action String
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
params Map<String, String>
getter/setter pair
resolvedQuery String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) NlpResult